clj-commons.digest

Message digest algorithms for Clojure

Message digest algorithms for Clojure
raw docstring

*buffer-size*clj

source

algorithm?clj

(algorithm? algorithm)

Returns true if algorithm is supported by the current JVM.

Returns true if algorithm is supported by the current JVM.
sourceraw docstring

algorithmsclj

(algorithms)

List supported digest algorithms.

List supported digest algorithms.
sourceraw docstring

bytes->hexclj

(bytes->hex bytes)

Returns a lowercase hexadecimal string for byte array, or nil for nil.

Returns a lowercase hexadecimal string for byte array, or nil for nil.
sourceraw docstring

digestclj

(digest algorithm message)
(digest algorithm message encoding)

Returns digest for message with given algorithm.

Returns digest for message with given algorithm.
sourceraw docstring

digest!clj

(digest! context)

Finalize a digest or HMAC context and return its bytes.

Finalize a digest or HMAC context and return its bytes.
sourceraw docstring

digest-base64clj

(digest-base64 algorithm message)
(digest-base64 algorithm message encoding)

Returns base64-encoded digest for message with given algorithm.

Returns base64-encoded digest for message with given algorithm.
sourceraw docstring

digest-bytesclj

(digest-bytes algorithm message)
(digest-bytes algorithm message encoding)

Returns digest bytes for message with given algorithm.

Returns digest bytes for message with given algorithm.
sourceraw docstring

digest-contextclj

(digest-context algorithm)
(digest-context algorithm encoding)

Create a stateful digest context for algorithm.

Create a stateful digest context for algorithm.
sourceraw docstring

Digestiblecljprotocol

-update-digest!clj

(-update-digest! message algorithm encoding)

-update-mac!clj

(-update-mac! message mac encoding)
source

file-digestclj

(file-digest algorithm file)

Returns digest for file with given algorithm.

Returns digest for file with given algorithm.
sourceraw docstring

file-sha-256clj

(file-sha-256 file)

Returns SHA-256 digest for file.

Returns SHA-256 digest for file.
sourceraw docstring

finalize!clj

Alias for digest!.

Alias for digest!.
sourceraw docstring

hex->bytesclj

(hex->bytes hex)

Returns bytes for a hexadecimal string, or nil for nil.

Hexadecimal input is case-insensitive and must contain an even number of valid hexadecimal characters.

Returns bytes for a hexadecimal string, or nil for nil.

Hexadecimal input is case-insensitive and must contain an even number of
valid hexadecimal characters.
sourceraw docstring

hmacclj

(hmac algorithm key message)
(hmac algorithm key message encoding)

Returns hex-encoded HMAC for message with given HMAC algorithm and key.

Returns hex-encoded HMAC for message with given HMAC algorithm and key.
sourceraw docstring

hmac-base64clj

(hmac-base64 algorithm key message)
(hmac-base64 algorithm key message encoding)

Returns base64-encoded HMAC for message with given HMAC algorithm and key.

Returns base64-encoded HMAC for message with given HMAC algorithm and key.
sourceraw docstring

hmac-bytesclj

(hmac-bytes algorithm key message)
(hmac-bytes algorithm key message encoding)

Returns HMAC bytes for message with given HMAC algorithm and key.

Returns HMAC bytes for message with given HMAC algorithm and key.
sourceraw docstring

hmac-contextclj

(hmac-context algorithm key)
(hmac-context algorithm key encoding)

Create a stateful HMAC context for algorithm and key.

Create a stateful HMAC context for algorithm and key.
sourceraw docstring

hmac-sha-256clj

(hmac-sha-256 key message)

Returns hex-encoded HMAC-SHA-256 for message and key.

Returns hex-encoded HMAC-SHA-256 for message and key.
sourceraw docstring

hmac-sha1clj

(hmac-sha1 key message)

Returns hex-encoded HMAC-SHA-1 for message and key.

Returns hex-encoded HMAC-SHA-1 for message and key.
sourceraw docstring

hmac-sha3-224clj

(hmac-sha3-224 key message)

Returns hex-encoded HMAC-SHA3-224 for message and key.

Returns hex-encoded HMAC-SHA3-224 for message and key.
sourceraw docstring

hmac-sha3-256clj

(hmac-sha3-256 key message)

Returns hex-encoded HMAC-SHA3-256 for message and key.

Returns hex-encoded HMAC-SHA3-256 for message and key.
sourceraw docstring

hmac-sha3-384clj

(hmac-sha3-384 key message)

Returns hex-encoded HMAC-SHA3-384 for message and key.

Returns hex-encoded HMAC-SHA3-384 for message and key.
sourceraw docstring

hmac-sha3-512clj

(hmac-sha3-512 key message)

Returns hex-encoded HMAC-SHA3-512 for message and key.

Returns hex-encoded HMAC-SHA3-512 for message and key.
sourceraw docstring

hmac-sha384clj

(hmac-sha384 key message)

Returns hex-encoded HMAC-SHA-384 for message and key.

Returns hex-encoded HMAC-SHA-384 for message and key.
sourceraw docstring

hmac-sha512clj

(hmac-sha512 key message)

Returns hex-encoded HMAC-SHA-512 for message and key.

Returns hex-encoded HMAC-SHA-512 for message and key.
sourceraw docstring

IncrementalContextcljprotocol

-context-encodingclj

(-context-encoding context)

-finalize-context!clj

(-finalize-context! context)

-reset-context!clj

(-reset-context! context)

-update-context!clj

(-update-context! context message encoding)
source

md2clj

(md2 message)

Encode the given message with the MD2 algorithm.

Encode the given message with the MD2 algorithm.
sourceraw docstring

md5clj

(md5 message)

Encode the given message with the MD5 algorithm.

Encode the given message with the MD5 algorithm.
sourceraw docstring

reset!clj

(reset! context)

Reset a digest or HMAC context, returning the context.

Reset a digest or HMAC context, returning the context.
sourceraw docstring

secure-eq?clj

(secure-eq? a b)
(secure-eq? a b encoding)

Constant-time equality for digest or HMAC byte arrays.

With a third argument of :hex or :base64, decodes two digest strings before comparing their bytes. Use this for secret or attacker-controlled digest/signature verification instead of = to avoid timing side channels.

Constant-time equality for digest or HMAC byte arrays.

With a third argument of `:hex` or `:base64`, decodes two digest strings
before comparing their bytes. Use this for secret or attacker-controlled
digest/signature verification instead of `=` to avoid timing side channels.
sourceraw docstring

shaclj

(sha message)

Encode the given message with the SHA algorithm.

Encode the given message with the SHA algorithm.
sourceraw docstring

sha-1clj

(sha-1 message)

Encode the given message with the SHA-1 algorithm.

Encode the given message with the SHA-1 algorithm.
sourceraw docstring

sha-224clj

(sha-224 message)

Encode the given message with the SHA-224 algorithm.

Encode the given message with the SHA-224 algorithm.
sourceraw docstring

sha-256clj

(sha-256 message)

Encode the given message with the SHA-256 algorithm.

Encode the given message with the SHA-256 algorithm.
sourceraw docstring

sha-384clj

(sha-384 message)

Encode the given message with the SHA-384 algorithm.

Encode the given message with the SHA-384 algorithm.
sourceraw docstring

sha-512clj

(sha-512 message)

Encode the given message with the SHA-512 algorithm.

Encode the given message with the SHA-512 algorithm.
sourceraw docstring

sha1clj

(sha1 message)

Encode the given message with the SHA1 algorithm.

Encode the given message with the SHA1 algorithm.
sourceraw docstring

sha224clj

(sha224 message)

Encode the given message with the SHA224 algorithm.

Encode the given message with the SHA224 algorithm.
sourceraw docstring

sha256clj

(sha256 message)

Encode the given message with the SHA256 algorithm.

Encode the given message with the SHA256 algorithm.
sourceraw docstring

sha3-224clj

(sha3-224 message)

Encode the given message with the SHA3-224 algorithm.

Encode the given message with the SHA3-224 algorithm.
sourceraw docstring

sha3-256clj

(sha3-256 message)

Encode the given message with the SHA3-256 algorithm.

Encode the given message with the SHA3-256 algorithm.
sourceraw docstring

sha3-384clj

(sha3-384 message)

Encode the given message with the SHA3-384 algorithm.

Encode the given message with the SHA3-384 algorithm.
sourceraw docstring

sha3-512clj

(sha3-512 message)

Encode the given message with the SHA3-512 algorithm.

Encode the given message with the SHA3-512 algorithm.
sourceraw docstring

sha384clj

(sha384 message)

Encode the given message with the SHA384 algorithm.

Encode the given message with the SHA384 algorithm.
sourceraw docstring

sha512clj

(sha512 message)

Encode the given message with the SHA512 algorithm.

Encode the given message with the SHA512 algorithm.
sourceraw docstring

shake128clj

(shake128 message)

Encode the given message with the SHAKE128 algorithm.

Encode the given message with the SHAKE128 algorithm.
sourceraw docstring

shake128-256clj

(shake128-256 message)

Encode the given message with the SHAKE128-256 algorithm.

Encode the given message with the SHAKE128-256 algorithm.
sourceraw docstring

shake256clj

(shake256 message)

Encode the given message with the SHAKE256 algorithm.

Encode the given message with the SHAKE256 algorithm.
sourceraw docstring

shake256-512clj

(shake256-512 message)

Encode the given message with the SHAKE256-512 algorithm.

Encode the given message with the SHAKE256-512 algorithm.
sourceraw docstring

standard-algorithmsclj

Standard digest algorithms with statically generated convenience functions.

Standard digest algorithms with statically generated convenience functions.
sourceraw docstring

update!clj

(update! context message)
(update! context message encoding)

Update a digest or HMAC context with message, returning the context.

Update a digest or HMAC context with message, returning the context.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries